==> sirikali_1.4.2.orig.tar.xz: SiriKali-1.4.2/src/engines/gocryptfscreateoptions.h <==
/*
 *
 *  Copyright (c) 2017
 *  name : Francis Banyikwa
 *  email: mhogomchungu@gmail.com
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef GOCRYPTFSCREATEOPTIONS_H
#define GOCRYPTFSCREATEOPTIONS_H

#include <functional>
#include <utility>

#include <QCloseEvent>
#include <QString>
#include <QDialog>

#include "../engines.h"

namespace Ui {
class gocryptfscreateoptions;
}

class gocryptfscreateoptions : public QDialog
{
	Q_OBJECT
public:
	static void instance( QWidget * parent,std::function< void( const engines::engine::Options& ) > function )
	{
                new gocryptfscreateoptions( parent,std::move( function ) ) ;
	}
	gocryptfscreateoptions( QWidget * parent,std::function< void( const engines::engine::Options& ) > ) ;
        ~gocryptfscreateoptions() ;
private slots:
	void pbSelectConfigPath() ;
	void pbOK() ;
	void pbCancel() ;
private:
	void HideUI( const engines::engine::Options& = engines::engine::Options() ) ;
	void closeEvent( QCloseEvent * ) ;
        Ui::gocryptfscreateoptions * m_ui ;
	std::function< void( const engines::engine::Options& ) > m_function ;
};

#endif // GOCRYPTFSCREATEOPTIONS_H

==> sirikali_1.5.0.orig.tar.xz: SiriKali-1.5.0/src/engines/gocryptfscreateoptions.h <==
/*
 *
 *  Copyright (c) 2017
 *  name : Francis Banyikwa
 *  email: mhogomchungu@gmail.com
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef GOCRYPTFSCREATEOPTIONS_H
#define GOCRYPTFSCREATEOPTIONS_H

#include <functional>
#include <utility>

#include <QCloseEvent>
#include <QString>
#include <QDialog>

#include "../engines.h"

namespace Ui {
class gocryptfscreateoptions;
}

class gocryptfscreateoptions : public QDialog
{
	Q_OBJECT
public:
	static void instance( const engines::engine& engine,
			      const engines::engine::createGUIOptions& s )
	{
		new gocryptfscreateoptions( engine,s ) ;
	}
	gocryptfscreateoptions( const engines::engine&,const engines::engine::createGUIOptions& ) ;
        ~gocryptfscreateoptions() ;
private slots:
	void pbSelectConfigPath() ;
	void pbOK() ;
	void pbCancel() ;
private:
	void HideUI( const engines::engine::cOpts& = engines::engine::cOpts() ) ;
	void closeEvent( QCloseEvent * ) ;
        Ui::gocryptfscreateoptions * m_ui ;
	QString m_configFileName ;
	engines::engine::fcreate m_function ;
};

#endif // GOCRYPTFSCREATEOPTIONS_H
